summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJuha Alanen <juha.alanen@mapbox.com>2020-04-20 14:55:40 +0300
committerJuha Alanen <juha.alanen@mapbox.com>2020-04-21 11:04:04 +0300
commit6fa9eda136ce4a4ee3b8509371bd269310e1b9c9 (patch)
tree98c4a7ceb15f928619db84419919337a991f4207
parent4be8c1ac3456190b94ebc527a46b783d7133a1f0 (diff)
downloadqtlocation-mapboxgl-6fa9eda136ce4a4ee3b8509371bd269310e1b9c9.tar.gz
[benchmark] Increase threshold to 15%
-rwxr-xr-xscripts/check_benchmark_results.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/scripts/check_benchmark_results.sh b/scripts/check_benchmark_results.sh
index 9ea1ca2c1e..0637dc1898 100755
--- a/scripts/check_benchmark_results.sh
+++ b/scripts/check_benchmark_results.sh
@@ -4,12 +4,12 @@
# check_benchmark_results.sh <baseline> <results> <comparison report in txt> <comparison report in html>
# Benchmark comparison script uses a hard-coded 5% threshold by default, but it causes random failures
# Increase the threshold to 10%
if [ "$(uname)" == "Darwin" ]; then
- sed -i '' s/"if res > 0.05"/"if res > 0.1"/ $PWD/vendor/benchmark/tools/gbench/report.py
+ sed -i '' s/"if res > 0.05"/"if res > 0.15"/ $PWD/vendor/benchmark/tools/gbench/report.py
elif [ "$(expr substr $(uname -s) 1 5)" == "Linux" ]; then
- sed -i s/"if res > 0.05"/"if res > 0.1"/ $PWD/vendor/benchmark/tools/gbench/report.py
+ sed -i s/"if res > 0.05"/"if res > 0.15"/ $PWD/vendor/benchmark/tools/gbench/report.py
fi
# Run the bencmark comparison
@@ -21,7 +21,7 @@ tests=`fgrep mean $3 | cut -c1-85 | grep 91m`
if [ -z "$tests" ]
then
echo "" >> $3
- echo "PASSED, all benchmarks within 10% threshold" >> $3
+ echo "PASSED, all benchmarks within 15% threshold" >> $3
ansi2html < $3 > $4
exit 0
@@ -29,7 +29,7 @@ else
test_names=`fgrep mean $3 | cut -c1-85 | grep 91m | cut -f1 -d' '`
echo "" >> $3
- echo "FAILED, following benchmarks are not within 10% threshold:" >> $3
+ echo "FAILED, following benchmarks are not within 15% threshold:" >> $3
echo "" >> $3
for t in $test_names;
do
@@ -4,12 +4,12 @@
# check_benchmark_results.sh <baseline> <results> <comparison report in txt> <comparison report in html>
# Benchmark comparison script uses a hard-coded 5% threshold by default, but it causes random failures
-# Increase the threshold to 10%
+# Increase the threshold to 15%
if [ "$(uname)" == "Darwin" ]; then